@@ -15,9 +15,6 @@
  */
 package jp.sf.pal.addresslist.bean;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import java.util.Calendar;
 import java.util.Date;
 
@@ -32,16 +29,21 @@ import jp.sf.pal.addresslist.model.Telecom;
 import jp.sf.pal.addresslist.model.User;
 import jp.sf.pal.addresslist.util.AddressListDaoUtil;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import org.seasar.portlet.util.PortletConfigUtil;
+import org.seasar.portlet.util.PortletResourceBundleUtil;
+
 import com.marevol.utils.faces.application.FacesMessageUtil;
-import com.marevol.utils.portlet.faces.PortletConfigUtil;
-import com.marevol.utils.portlet.faces.PortletResourceBundleUtil;
+import com.marevol.utils.faces.util.LocaleUtil;
 
 public class AddressListAddPageBean
 {
     /**
      * Logger for this class
      */
-    private static final Log log = LogFactory.getLog(AddressListAddPageBean.class);
+    private static final Log log = LogFactory
+            .getLog(AddressListAddPageBean.class);
 
     private String familyname;
 
@@ -212,9 +214,13 @@ public class AddressListAddPageBean
             log.debug("save() - start");
         }
 
-        String publicListString = PortletConfigUtil.getInitParameter(AddressListConstants.PUBLIC_LIST_PARAM);
-        String username = FacesContext.getCurrentInstance().getExternalContext().getRemoteUser();
-        if ((publicListString != null && publicListString.equalsIgnoreCase("true")) || username != null)
+        String publicListString = PortletConfigUtil
+                .getInitParameter(AddressListConstants.PUBLIC_LIST_PARAM);
+        String username = FacesContext.getCurrentInstance()
+                .getExternalContext().getRemoteUser();
+        if ((publicListString != null && publicListString
+                .equalsIgnoreCase("true"))
+                || username != null)
         {
 
             if (username == null)
@@ -284,7 +290,8 @@ public class AddressListAddPageBean
                 hTelephone.setLoccode(homeTelephoneLoccode);
                 hTelephone.setNum(new Integer(0));
                 hTelephone.setNumber(homeTelephoneNumber);
-                hTelephone.setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
+                hTelephone
+                        .setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
                 hTelephone.setUser(user);
 
                 AddressListDaoUtil.getTelecomDao().save(hTelephone);
@@ -336,7 +343,8 @@ public class AddressListAddPageBean
                 bTelephone.setLoccode(businessTelephoneLoccode);
                 bTelephone.setNum(new Integer(0));
                 bTelephone.setNumber(businessTelephoneNumber);
-                bTelephone.setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
+                bTelephone
+                        .setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
                 bTelephone.setUser(user);
 
                 AddressListDaoUtil.getTelecomDao().save(bTelephone);
@@ -522,7 +530,8 @@ public class AddressListAddPageBean
 
                 // i18n
                 FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.AddedAddress"));
+                        .getString(LocaleUtil.getLocale(),
+                                "addresslistaddpagebean.AddedAddress"));
 
                 if (log.isDebugEnabled())
                 {
@@ -536,7 +545,9 @@ public class AddressListAddPageBean
 
                 // i18n
                 FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.FailedToAddIt"), e.toString());
+                        .getString(LocaleUtil.getLocale(),
+                                "addresslistaddpagebean.FailedToAddIt"), e
+                        .toString());
 
                 if (log.isDebugEnabled())
                 {
@@ -549,7 +560,9 @@ public class AddressListAddPageBean
         {
             // i18n
             FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                    .getString("addresslistaddpagebean.FailedToAddIt"), "Invalid User.");
+                    .getString(LocaleUtil.getLocale(),
+                            "addresslistaddpagebean.FailedToAddIt"),
+                    "Invalid User.");
 
             if (log.isDebugEnabled())
             {
@@ -568,12 +581,15 @@ public class AddressListAddPageBean
     public SelectItem[] getGenderItems()
     {
         return new SelectItem[] {
-                new SelectItem(AddressListConstants.GENDER_NONE, PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.None")),
-                new SelectItem(AddressListConstants.GENDER_MALE, PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.Male")),
-                new SelectItem(AddressListConstants.GENDER_FEMALE, PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.Female")) };
+                new SelectItem(AddressListConstants.GENDER_NONE,
+                        PortletResourceBundleUtil.getString(LocaleUtil
+                                .getLocale(), "addresslistaddpagebean.None")),
+                new SelectItem(AddressListConstants.GENDER_MALE,
+                        PortletResourceBundleUtil.getString(LocaleUtil
+                                .getLocale(), "addresslistaddpagebean.Male")),
+                new SelectItem(AddressListConstants.GENDER_FEMALE,
+                        PortletResourceBundleUtil.getString(LocaleUtil
+                                .getLocale(), "addresslistaddpagebean.Female")) };
     }
 
     /**
