@@ -32,17 +32,19 @@ import jp.sf.pal.addresslist.util.AddressListDaoUtil;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.seasar.portlet.util.PortletConfigUtil;
+import org.seasar.portlet.util.PortletResourceBundleUtil;
 
 import com.marevol.utils.faces.application.FacesMessageUtil;
-import com.marevol.utils.portlet.faces.PortletConfigUtil;
-import com.marevol.utils.portlet.faces.PortletResourceBundleUtil;
+import com.marevol.utils.faces.util.LocaleUtil;
 
 public class AddressListEditPageBean
 {
     /**
      * Logger for this class
      */
-    private static final Log log = LogFactory.getLog(AddressListEditPageBean.class);
+    private static final Log log = LogFactory
+            .getLog(AddressListEditPageBean.class);
 
     private AddressListSessionBean addressListSession;
 
@@ -225,14 +227,19 @@ public class AddressListEditPageBean
         if (getId() == null)
         {
             FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                    .getString("addresslisteditpagebean.TheAddressIsNull"));
+                    .getString(LocaleUtil.getLocale(),
+                            "addresslisteditpagebean.TheAddressIsNull"));
             log.error("user " + getId().longValue() + " is null.");
             return AddressListConstants.ADDRESSLISTVIEW_VIEW_ID;
         }
 
-        String publicListString = PortletConfigUtil.getInitParameter(AddressListConstants.PUBLIC_LIST_PARAM);
-        String username = FacesContext.getCurrentInstance().getExternalContext().getRemoteUser();
-        if ((publicListString != null && publicListString.equalsIgnoreCase("true")) || username != null)
+        String publicListString = PortletConfigUtil
+                .getInitParameter(AddressListConstants.PUBLIC_LIST_PARAM);
+        String username = FacesContext.getCurrentInstance()
+                .getExternalContext().getRemoteUser();
+        if ((publicListString != null && publicListString
+                .equalsIgnoreCase("true"))
+                || username != null)
         {
             //            if (username == null)
             //            {
@@ -241,12 +248,16 @@ public class AddressListEditPageBean
 
             try
             {
-                User user = AddressListDaoUtil.getUserDao().getUserById(getId().longValue());
+                User user = AddressListDaoUtil.getUserDao().getUserById(
+                        getId().longValue());
                 if (user == null)
                 {
-                    FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                            .getString("addresslisteditpagebean.TheAddressIsNull"));
-                    log.error("user " + getId().longValue() + " does not exist in db.");
+                    FacesMessageUtil
+                            .addErrorMessage(PortletResourceBundleUtil
+                                    .getString(LocaleUtil.getLocale(),
+                                            "addresslisteditpagebean.TheAddressIsNull"));
+                    log.error("user " + getId().longValue()
+                            + " does not exist in db.");
                     return AddressListConstants.ADDRESSLISTVIEW_VIEW_ID;
                 }
 
@@ -309,7 +320,8 @@ public class AddressListEditPageBean
                 hTelephone.setLoccode(homeTelephoneLoccode);
                 hTelephone.setNum(new Integer(0));
                 hTelephone.setNumber(homeTelephoneNumber);
-                hTelephone.setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
+                hTelephone
+                        .setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
                 hTelephone.setUser(user);
 
                 AddressListDaoUtil.getTelecomDao().saveOrUpdate(hTelephone);
@@ -361,7 +373,8 @@ public class AddressListEditPageBean
                 bTelephone.setLoccode(businessTelephoneLoccode);
                 bTelephone.setNum(new Integer(0));
                 bTelephone.setNumber(businessTelephoneNumber);
-                bTelephone.setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
+                bTelephone
+                        .setTelecomtype(AddressListConstants.TELECOMTYPE_TELEPHONE);
                 bTelephone.setUser(user);
 
                 AddressListDaoUtil.getTelecomDao().saveOrUpdate(bTelephone);
@@ -547,7 +560,8 @@ public class AddressListEditPageBean
 
                 // i18n
                 FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil
-                        .getString("addresslisteditpagebean.UpdatedTheAddress"));
+                        .getString(LocaleUtil.getLocale(),
+                                "addresslisteditpagebean.UpdatedTheAddress"));
 
                 if (log.isDebugEnabled())
                 {
@@ -561,7 +575,9 @@ public class AddressListEditPageBean
 
                 // i18n
                 FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                        .getString("addresslisteditpagebean.FailedToUpdateIt"), e.toString());
+                        .getString(LocaleUtil.getLocale(),
+                                "addresslisteditpagebean.FailedToUpdateIt"), e
+                        .toString());
 
                 if (log.isDebugEnabled())
                 {
@@ -574,7 +590,9 @@ public class AddressListEditPageBean
         {
             // i18n
             FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                    .getString("addresslisteditpagebean.FailedToUpdateIt"), "Invalid User.");
+                    .getString(LocaleUtil.getLocale(),
+                            "addresslisteditpagebean.FailedToUpdateIt"),
+                    "Invalid User.");
 
             if (log.isDebugEnabled())
             {
@@ -597,12 +615,14 @@ public class AddressListEditPageBean
         {
             try
             {
-                User user = AddressListDaoUtil.getUserDao().getUserById(id.longValue());
+                User user = AddressListDaoUtil.getUserDao().getUserById(
+                        id.longValue());
                 AddressListDaoUtil.getUserDao().delete(user);
 
                 // i18n
                 FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil
-                        .getString("addresslisteditpagebean.DeletedTheAddress"));
+                        .getString(LocaleUtil.getLocale(),
+                                "addresslisteditpagebean.DeletedTheAddress"));
 
                 if (log.isDebugEnabled())
                 {
@@ -616,7 +636,9 @@ public class AddressListEditPageBean
 
                 // i18n
                 FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                        .getString("addresslisteditpagebean.FailedToDeleteIt"), e.toString());
+                        .getString(LocaleUtil.getLocale(),
+                                "addresslisteditpagebean.FailedToDeleteIt"), e
+                        .toString());
 
                 if (log.isDebugEnabled())
                 {
@@ -629,7 +651,8 @@ public class AddressListEditPageBean
         {
             // i18n
             FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
-                    .getString("addresslisteditpagebean.TheAddressIsNull"));
+                    .getString(LocaleUtil.getLocale(),
+                            "addresslisteditpagebean.TheAddressIsNull"));
 
             if (log.isDebugEnabled())
             {
@@ -647,12 +670,15 @@ public class AddressListEditPageBean
     public SelectItem[] getGenderItems()
     {
         return new SelectItem[] {
-                new SelectItem(AddressListConstants.GENDER_NONE, PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.None")),
-                new SelectItem(AddressListConstants.GENDER_MALE, PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.Male")),
-                new SelectItem(AddressListConstants.GENDER_FEMALE, PortletResourceBundleUtil
-                        .getString("addresslistaddpagebean.Female")) };
+                new SelectItem(AddressListConstants.GENDER_NONE,
+                        PortletResourceBundleUtil.getString(LocaleUtil
+                                .getLocale(), "addresslistaddpagebean.None")),
+                new SelectItem(AddressListConstants.GENDER_MALE,
+                        PortletResourceBundleUtil.getString(LocaleUtil
+                                .getLocale(), "addresslistaddpagebean.Male")),
+                new SelectItem(AddressListConstants.GENDER_FEMALE,
+                        PortletResourceBundleUtil.getString(LocaleUtil
+                                .getLocale(), "addresslistaddpagebean.Female")) };
     }
 
     public Boolean getValidUser()
@@ -705,20 +731,29 @@ public class AddressListEditPageBean
             setNickname(user.getNickname());
 
             setOwner(user.getOwner());
-            String username = FacesContext.getCurrentInstance().getExternalContext().getRemoteUser();
+            String username = FacesContext.getCurrentInstance()
+                    .getExternalContext().getRemoteUser();
             if (username == null)
             {
                 username = AddressListConstants.GUEST_USERNAME;
             }
-            String publicListString = PortletConfigUtil.getInitParameter(AddressListConstants.PUBLIC_LIST_PARAM);
+            String publicListString = PortletConfigUtil
+                    .getInitParameter(AddressListConstants.PUBLIC_LIST_PARAM);
             if (log.isDebugEnabled())
             {
-                log.debug("setAddressListSession(AddressListSessionBean) - owner=" + owner + ", username=" + username
-                        + ", publicListString=" + publicListString);
+                log
+                        .debug("setAddressListSession(AddressListSessionBean) - owner="
+                                + owner
+                                + ", username="
+                                + username
+                                + ", publicListString=" + publicListString);
             }
-            if (publicListString != null && publicListString.equalsIgnoreCase("true"))
+            if (publicListString != null
+                    && publicListString.equalsIgnoreCase("true"))
             {
-                if (username.equals(getOwner()) || getOwner().equals(AddressListConstants.GUEST_USERNAME))
+                if (username.equals(getOwner())
+                        || getOwner().equals(
+                                AddressListConstants.GUEST_USERNAME))
                 {
                     validUser = Boolean.TRUE;
                 }
