@@ -15,9 +15,9 @@
  */
 package jp.sf.pal.addresslist.portlet;
 
-import jp.sf.pal.myfaces.portlet.MyFacesGenericPortlet;
+import org.seasar.teeda.core.portlet.FacesPortlet;
 
-public class AddressListPortlet extends MyFacesGenericPortlet
+public class AddressListPortlet extends FacesPortlet
 {
 
 }
